.. _supervisor_module:

:mod:`fabtools.supervisor`
--------------------------

.. automodule:: fabtools.supervisor

    .. seealso:: :ref:`require_supervisor_module`

    Manage supervisord
    ~~~~~~~~~~~~~~~~~~

    .. autofunction:: reload_config
    .. autofunction:: update_config

    Manage processes
    ~~~~~~~~~~~~~~~~

    .. autofunction:: process_status
    .. autofunction:: start_process
    .. autofunction:: stop_process
    .. autofunction:: restart_process
